@@ -15,6 +15,7 @@
 """Contains classes concerning Wav2Vec2ForCTC."""
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class Wav2Vec2ForCTC(AnnotatorModel,
@@ -86,6 +87,8 @@ class Wav2Vec2ForCTC(AnnotatorModel,
     """
     name = "Wav2Vec2ForCTC"
 
+    inputAnnotatorTypes = [AnnotatorType.AUDIO]
+
     configProtoBytes = Param(Params._dummy(),
                              "configProtoBytes",
                              "ConfigProto from tensorflow, serialized into byte array. Get with "
