@@ -14,6 +14,7 @@
 """Contains classes for BertForTokenClassification."""
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class BertForTokenClassification(AnnotatorModel,
@@ -94,6 +95,8 @@ class BertForTokenClassification(AnnotatorModel,
     """
     name = "BertForTokenClassification"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT, AnnotatorType.TOKEN]
+
     maxSentenceLength = Param(Params._dummy(),
                               "maxSentenceLength",
                               "Max sentence length to process",
