@@ -12,14 +12,14 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 """Contains classes for DeBertaForSequenceClassification."""
-
 from sparknlp.common import *
 
 
 class DeBertaForSequenceClassification(AnnotatorModel,
                                        HasCaseSensitiveProperties,
                                        HasBatchedAnnotate,
-                                       HasClassifierActivationProperties):
+                                       HasClassifierActivationProperties,
+                                       HasEngine):
     """DeBertaForSequenceClassification can load DeBERTa v2 & v3 Models with sequence classification/regression head on
     top (a linear layer on top of the pooled output) e.g. for multi-class document classification tasks.
 
@@ -97,6 +97,8 @@ class DeBertaForSequenceClassification(AnnotatorModel,
     """
     name = "DeBertaForSequenceClassification"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT, AnnotatorType.TOKEN]
+
     maxSentenceLength = Param(Params._dummy(),
                               "maxSentenceLength",
                               "Max sentence length to process",
