@@ -13,13 +13,14 @@
 #  limitations under the License.
 """Contains classes for RoBertaForTokenClassification."""
 
-
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class RoBertaForTokenClassification(AnnotatorModel,
                                     HasCaseSensitiveProperties,
-                                    HasBatchedAnnotate):
+                                    HasBatchedAnnotate,
+                                    HasEngine):
     """RoBertaForTokenClassification can load RoBerta Models with a token
     classification head on top (a linear layer on top of the hidden-states
     output) e.g. for Named-Entity-Recognition (NER) tasks.
@@ -92,6 +93,8 @@ class RoBertaForTokenClassification(AnnotatorModel,
     """
     name = "RoBertaForTokenClassification"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT, AnnotatorType.TOKEN]
+
     maxSentenceLength = Param(Params._dummy(),
                               "maxSentenceLength",
                               "Max sentence length to process",
@@ -183,4 +186,3 @@ class RoBertaForTokenClassification(AnnotatorModel,
         """
         from sparknlp.pretrained import ResourceDownloader
         return ResourceDownloader.downloadModel(RoBertaForTokenClassification, name, lang, remote_loc)
-
