@@ -13,13 +13,14 @@
 #  limitations under the License.
 """Contains classes for XlmRoBertaForTokenClassification."""
 
-
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class XlmRoBertaForTokenClassification(AnnotatorModel,
                                        HasCaseSensitiveProperties,
-                                       HasBatchedAnnotate):
+                                       HasBatchedAnnotate,
+                                       HasEngine):
     """XlmRoBertaForTokenClassification can load XLM-RoBERTa Models with a token
     classification head on top (a linear layer on top of the hidden-states
     output) e.g. for Named-Entity-Recognition (NER) tasks.
@@ -90,6 +91,8 @@ class XlmRoBertaForTokenClassification(AnnotatorModel,
     """
     name = "XlmRoBertaForTokenClassification"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT, AnnotatorType.TOKEN]
+
     maxSentenceLength = Param(Params._dummy(),
                               "maxSentenceLength",
                               "Max sentence length to process",
@@ -181,4 +184,3 @@ class XlmRoBertaForTokenClassification(AnnotatorModel,
         """
         from sparknlp.pretrained import ResourceDownloader
         return ResourceDownloader.downloadModel(XlmRoBertaForTokenClassification, name, lang, remote_loc)
-
