@@ -14,6 +14,7 @@
 """Contains classes for XlnetForTokenClassification."""
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class XlnetForTokenClassification(AnnotatorModel,
@@ -93,6 +94,8 @@ class XlnetForTokenClassification(AnnotatorModel,
 
     name = "XlnetForTokenClassification"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT, AnnotatorType.TOKEN]
+
     maxSentenceLength = Param(Params._dummy(),
                               "maxSentenceLength",
                               "Max sentence length to process",
