@@ -14,6 +14,7 @@
 """Contains classes for the UniversalSentenceEncoder."""
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class UniversalSentenceEncoder(AnnotatorModel,
@@ -120,6 +121,8 @@ class UniversalSentenceEncoder(AnnotatorModel,
 
     name = "UniversalSentenceEncoder"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT]
+
     loadSP = Param(Params._dummy(), "loadSP",
                    "Whether to load SentencePiece ops file which is required only by multi-lingual models. "
                    "This is not changeable after it's set with a pretrained model nor it is compatible with Windows.",
