@@ -15,6 +15,7 @@
 
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class WordEmbeddings(AnnotatorApproach, HasEmbeddingsProperties, HasStorage):
@@ -114,6 +115,8 @@ class WordEmbeddings(AnnotatorApproach, HasEmbeddingsProperties, HasStorage):
 
     name = "WordEmbeddings"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT, AnnotatorType.TOKEN]
+
     writeBufferSize = Param(Params._dummy(),
                             "writeBufferSize",
                             "buffer size limit before dumping to disk storage while writing",
@@ -249,8 +252,11 @@ class WordEmbeddingsModel(AnnotatorModel, HasEmbeddingsProperties, HasStorageMod
     """
 
     name = "WordEmbeddingsModel"
+
     databases = ['EMBEDDINGS']
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT, AnnotatorType.TOKEN]
+
     readCacheSize = Param(Params._dummy(),
                           "readCacheSize",
                           "cache size for items retrieved from storage. Increase for performance but higher memory consumption",
