@@ -14,6 +14,7 @@
 """Contains classes for the ContextSpellChecker."""
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class ContextSpellCheckerApproach(AnnotatorApproach):
@@ -138,6 +139,8 @@ class ContextSpellCheckerApproach(AnnotatorApproach):
 
     name = "ContextSpellCheckerApproach"
 
+    inputAnnotatorTypes = [AnnotatorType.TOKEN]
+
     languageModelClasses = Param(Params._dummy(),
                                  "languageModelClasses",
                                  "Number of classes to use during factorization of the softmax output in the LM.",
@@ -461,7 +464,8 @@ class ContextSpellCheckerApproach(AnnotatorApproach):
     def _create_model(self, java_model):
         return ContextSpellCheckerModel(java_model=java_model)
 
-class ContextSpellCheckerModel(AnnotatorModel):
+
+class ContextSpellCheckerModel(AnnotatorModel, HasEngine):
     """Implements a deep-learning based Noisy Channel Model Spell Algorithm.
     Correction candidates are extracted combining context information and word
     information.
@@ -569,6 +573,8 @@ class ContextSpellCheckerModel(AnnotatorModel):
     """
     name = "ContextSpellCheckerModel"
 
+    inputAnnotatorTypes = [AnnotatorType.TOKEN]
+
     wordMaxDistance = Param(Params._dummy(),
                             "wordMaxDistance",
                             "Maximum distance for the generated candidates for every word.",
@@ -801,4 +807,3 @@ class ContextSpellCheckerModel(AnnotatorModel):
         """
         from sparknlp.pretrained import ResourceDownloader
         return ResourceDownloader.downloadModel(ContextSpellCheckerModel, name, lang, remote_loc)
-
