@@ -15,6 +15,7 @@
 
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class RegexTokenizer(AnnotatorModel):
@@ -81,6 +82,8 @@ class RegexTokenizer(AnnotatorModel):
 
     name = "RegexTokenizer"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT]
+
     @keyword_only
     def __init__(self):
         super(RegexTokenizer, self).__init__(classname="com.johnsnowlabs.nlp.annotators.RegexTokenizer")
