@@ -15,6 +15,7 @@
 
 
 from sparknlp.common import *
+from sparknlp.common.annotator_type import AnnotatorType
 
 
 class Tokenizer(AnnotatorApproach):
@@ -87,6 +88,10 @@ class Tokenizer(AnnotatorApproach):
     +-----------------------------------------------------------------------+
     """
 
+    name = 'Tokenizer'
+
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT]
+
     targetPattern = Param(Params._dummy(),
                           "targetPattern",
                           "pattern to grab from text as token candidates. Defaults \S+",
@@ -147,8 +152,6 @@ class Tokenizer(AnnotatorApproach):
                       "Set the maximum allowed length for each token",
                       typeConverter=TypeConverters.toInt)
 
-    name = 'Tokenizer'
-
     @keyword_only
     def __init__(self):
         super(Tokenizer, self).__init__(classname="com.johnsnowlabs.nlp.annotators.Tokenizer")
@@ -429,6 +432,7 @@ class Tokenizer(AnnotatorApproach):
     def _create_model(self, java_model):
         return TokenizerModel(java_model=java_model)
 
+
 class TokenizerModel(AnnotatorModel):
     """Tokenizes raw text into word pieces, tokens. Identifies tokens with
     tokenization open standards. A few rules will help customizing it if
@@ -453,6 +457,8 @@ class TokenizerModel(AnnotatorModel):
     """
     name = "TokenizerModel"
 
+    inputAnnotatorTypes = [AnnotatorType.DOCUMENT]
+
     exceptions = Param(Params._dummy(),
                        "exceptions",
                        "Words that won't be affected by tokenization rules",
