@@ -40,5 +40,28 @@ class EntityRulerTestSpec(unittest.TestCase):
         pipeline = Pipeline(stages=[document_assembler, tokenizer, entity_ruler])
         model = pipeline.fit(self.data)
         result = model.transform(self.data)
-        assert result.select("entity").count() > 0
+        self.assertTrue(result.select("entity").count() > 0)
+
+
+@pytest.mark.fast
+class EntityRulerOneColumnTestSpec(unittest.TestCase):
+
+    def setUp(self):
+        self.data = SparkContextForTest.spark.createDataFrame([["John Snow lives in Winterfell"]]).toDF("text")
+        self.path = os.getcwd() + "/../src/test/resources/entity-ruler/keywords_only.json"
+
+    def runTest(self):
+        document_assembler = DocumentAssembler().setInputCol("text").setOutputCol("document")
+
+        entity_ruler = EntityRulerApproach() \
+            .setInputCols("document") \
+            .setOutputCol("entity") \
+            .setPatternsResource(self.path)
+
+        pipeline = Pipeline(stages=[document_assembler, entity_ruler])
+        model = pipeline.fit(self.data)
+        result = model.transform(self.data)
+        self.assertTrue(result.select("entity").count() > 0)
+
+
 
